==> cresce_ui-0.0.4.tar.gz: lib/c_login_card.dart <==
part of cresce_ui;

class CLoginCard extends StatelessWidget {
  const CLoginCard({Key? key}) : super(key: key);
  @override
  Widget build(BuildContext context) {
    return CModal(
      child: Column(
        children: const [
          _CHeader(),
        ],
      ),
    );
    /*
    return Stack(
      children: <Widget>[
        Pinned.fromPins(
          Pin(start: 0.0, end: 0.0),
          Pin(start: 0.0, end: 0.0),
          child:
              // Adobe XD layer: 'Card' (component)
              CCard(),
        ),
        Transform.translate(
          offset: Offset(16.1, 396.5),
          child: SizedBox(
            width: 291.0,
            height: 42.0,
            child:
                // Adobe XD layer: 'Button - Primary' (component)
                CButtonPrimary(),
          ),
        ),
        Transform.translate(
          offset: Offset(16.1, 243.0),
          child: SizedBox(
            width: 291.0,
            height: 21.0,
            child:
                // Adobe XD layer: 'Field - Primary' (component)
                CFieldPrimary(),
          ),
        ),
        Transform.translate(
          offset: Offset(16.1, 293.5),
          child: SizedBox(
            width: 291.0,
            height: 26.0,
            child:
                // Adobe XD layer: 'Field - Primary' (component)
                CFieldPrimary(),
          ),
        ),
      ],
    );
    */
  }
}

class _CHeader extends StatelessWidget {
  const _CHeader({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Stack(
      children: [
        const _CBannerLoginImage(),
        const _CBannerLogin(),
        Transform.translate(
          offset: const Offset(16, 45.3),
          child: Text(
            'Log In!',
            style: CAppTextStyles.titleSecondary,
          ),
        ),
        Transform.translate(
          offset: const Offset(16, 28.3),
          child: Text(
            'Welcome back,',
            style: CAppTextStyles.subtitleSecondary,
          ),
        ),
      ],
    );
  }
}

class _CBannerLogin extends StatelessWidget {
  const _CBannerLogin({Key? key}) : super(key: key);
  @override
  Widget build(BuildContext context) => const Image(
        image: AssetImage('assets/banner-login.png'),
      );
}

class _CBannerLoginImage extends StatelessWidget {
  const _CBannerLoginImage({Key? key}) : super(key: key);
  @override
  Widget build(BuildContext context) => const Image(
        image: AssetImage('assets/banner-login-lmage.png'),
      );
}

==> cresce_ui-0.0.5.tar.gz: lib/c_login_card.dart <==
part of cresce_ui;

class CLoginCard extends StatelessWidget {
  const CLoginCard({Key? key}) : super(key: key);
  @override
  Widget build(BuildContext context) {
    return CBigModal(
      child: Column(
        children: const [
          _CHeader(),
          Padding(
            padding: EdgeInsets.all(16.0),
            child: CInputText(label: 'Username'),
          ),
          Padding(
            padding: EdgeInsets.all(16.0),
            child: CInputText(label: 'Password', isPassword: true),
          ),
          Padding(
            padding: EdgeInsets.all(16.0),
            child: CButton(label: 'Login'),
          ),
        ],
      ),
    );
  }
}

class _CHeader extends StatelessWidget {
  const _CHeader({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Stack(
      children: [
        const _CBannerLoginImage(),
        const _CBannerLogin(),
        Transform.translate(
          offset: const Offset(16, 45.3),
          child: Text(
            'Log In!',
            style: CTextStyles.titleSecondary,
          ),
        ),
        Transform.translate(
          offset: const Offset(16, 28.3),
          child: Text(
            'Welcome back,',
            style: CTextStyles.subtitleSecondary,
          ),
        ),
      ],
    );
  }
}

class _CBannerLogin extends StatelessWidget {
  const _CBannerLogin({Key? key}) : super(key: key);
  @override
  Widget build(BuildContext context) => const Image(
        image: AssetImage('assets/banner-login.png'),
      );
}

class _CBannerLoginImage extends StatelessWidget {
  const _CBannerLoginImage({Key? key}) : super(key: key);
  @override
  Widget build(BuildContext context) => const Image(
        image: AssetImage('assets/banner-login-lmage.png'),
      );
}
